@@ -52,6 +52,7 @@ int main(int argc, char *argv[])
     if (args.isEmpty()) {
 
         QmlApplicationViewer viewer;
+        viewer.setAttribute(Qt::WA_NoSystemBackground);
 
         QDeclarativeContext *context = viewer.rootContext();
         ct.setView(&viewer);
@@ -74,7 +75,7 @@ int main(int argc, char *argv[])
         viewer.engine()->setNetworkAccessManagerFactory(factory);
 
 #ifdef Q_WS_MAEMO_5
-//        viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
+        //        viewer.engine()->addImportPath(QString("/opt/qtm12/imports"));
         //    viewer.engine()->addPluginPath(QString("/opt/qtm12/plugins"));
         viewer.engine()->setOfflineStoragePath("/home/user/.config/cutetube");
         QDir path;
@@ -86,7 +87,7 @@ int main(int argc, char *argv[])
         if (!path.exists()) {
             path.mkpath("/home/user/MyDocs/.cutetube");
         }
-        //    viewer.setViewport(new QGLWidget());
+//        viewer.setViewport(new QGLWidget());
 
         QString locale = ct.getLanguage();
 
@@ -116,7 +117,7 @@ int main(int argc, char *argv[])
         ct.getMediaPlayerFromDB();
         QObject::connect(&yt, SIGNAL(gotVideoUrl(QString)), &ct, SLOT(playVideo(QString)));
         QObject::connect(&yt, SIGNAL(videoUrlError()), &app, SLOT(quit()));
-        QObject::connect(&ct, SIGNAL(playbackStarted()), &app, SLOT(quit()));
+        QObject::connect(&ct, SIGNAL(playbackStarted(QString)), &app, SLOT(quit()));
         yt.setPlaybackQuality(quality);
         yt.getVideoUrl(playerUrl);
 
