@@ -695,22 +695,22 @@
         <location filename="../SettingsDialog.qml" line="37"/>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>High quality</source>
-        <translation type="unfinished">Hohe qualität</translation>
+        <translation>Hohe Qualität</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>360p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>480p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>720p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="43"/>
@@ -720,38 +720,38 @@
     <message>
         <location filename="../SettingsDialog.qml" line="44"/>
         <source>Most recent</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktuellste videos</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="44"/>
         <source>Most viewed</source>
-        <translation type="unfinished"></translation>
+        <translation>Meistgesehen</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="45"/>
         <source>Archive</source>
-        <translation type="unfinished">Archiv</translation>
+        <translation>Archiv</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="45"/>
         <source>Latest subscription videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Letzte abonnierte videos</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="46"/>
         <source>My uploads</source>
-        <translation type="unfinished"></translation>
+        <translation>Mein uploads</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="46"/>
         <source>My favourites</source>
-        <translation type="unfinished"></translation>
+        <translation>Mein favoriten</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="122"/>
         <location filename="../SettingsDialog.qml" line="173"/>
         <source>Network Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Netzwerk Proxy</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="146"/>
@@ -786,7 +786,7 @@
     <message>
         <location filename="../SettingsDialog.qml" line="411"/>
         <source>Widget</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="419"/>
@@ -831,12 +831,12 @@
     <message>
         <location filename="../SettingsDialog.qml" line="40"/>
         <source>On</source>
-        <translation>Auf</translation>
+        <translation>An</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="40"/>
         <source>Off</source>
-        <translation>Off</translation>
+        <translation>Aus</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="41"/>
@@ -921,7 +921,7 @@
         <location filename="../SettingsDialog.qml" line="158"/>
         <location filename="../SettingsDialog.qml" line="337"/>
         <source>Safe Search</source>
-        <translation>Sicher Suchlauf</translation>
+        <translation>Sicherer Modus</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="167"/>
@@ -957,22 +957,22 @@
     <message>
         <location filename="../SettingsDialog.qml" line="268"/>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Netzwerk</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="276"/>
         <source>Network proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Netzwerk proxy</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="293"/>
         <source>Media</source>
-        <translation type="unfinished"></translation>
+        <translation>Medien</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="327"/>
         <source>YouTube searches</source>
-        <translation type="unfinished"></translation>
+        <translation>YouTube suche</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="335"/>
@@ -982,7 +982,7 @@
     <message>
         <location filename="../SettingsDialog.qml" line="277"/>
         <source>None</source>
-        <translation></translation>
+        <translation>Kein proxy</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="346"/>
@@ -1003,7 +1003,7 @@
     <message>
         <location filename="../SubscriptionsView.qml" line="36"/>
         <source>Latest Subscriptions Videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Letzte abonnierte Videos</translation>
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="45"/>
