@@ -5,12 +5,12 @@
     <name>AboutDialog</name>
     <message>
         <location filename="../AboutDialog.qml" line="44"/>
-        <source>cuteTube-QML - 0.7.1</source>
-        <translation type="unfinished"></translation>
+        <source>cuteTube-QML - 0.7.3</source>
+        <translation></translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
-        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
+        <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
         <translation></translation>
     </message>
 </context>
@@ -95,13 +95,13 @@
 <context>
     <name>ArchiveListView</name>
     <message>
-        <location filename="../ArchiveListView.qml" line="27"/>
+        <location filename="../ArchiveListView.qml" line="33"/>
         <source>Deleted from archive</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="30"/>
-        <location filename="../ArchiveListView.qml" line="47"/>
+        <location filename="../ArchiveListView.qml" line="36"/>
+        <location filename="../ArchiveListView.qml" line="53"/>
         <source>Unable to delete from archive</source>
         <translation></translation>
     </message>
@@ -163,22 +163,22 @@
 <context>
     <name>Controller</name>
     <message>
-        <location filename="../../../controller.cpp" line="188"/>
+        <location filename="../../../controller.cpp" line="189"/>
         <source>Video deleted from device</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="191"/>
+        <location filename="../../../controller.cpp" line="192"/>
         <source>Unable to delete video</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="195"/>
+        <location filename="../../../controller.cpp" line="196"/>
         <source>Video not found</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="250"/>
+        <location filename="../../../controller.cpp" line="251"/>
         <source>Copied to clipboard</source>
         <translation></translation>
     </message>
@@ -214,6 +214,14 @@
         <translation></translation>
     </message>
 </context>
+<context>
+    <name>MenuBar</name>
+    <message>
+        <location filename="../MenuBar.qml" line="130"/>
+        <source>Sort</source>
+        <translation></translation>
+    </message>
+</context>
 <context>
     <name>MyAccountView</name>
     <message>
@@ -342,7 +350,7 @@
     <message>
         <location filename="../PlaylistVideosView.qml" line="59"/>
         <source>Video(s) deleted from playlist</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../PlaylistVideosView.qml" line="80"/>
@@ -412,54 +420,64 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="192"/>
+        <location filename="../SettingsDialog.qml" line="194"/>
         <source>Your saved searches have been cleared</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="195"/>
+        <location filename="../SettingsDialog.qml" line="197"/>
         <source>Database error. Unable to clear searches</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="242"/>
+        <location filename="../SettingsDialog.qml" line="244"/>
         <source>Settings</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="283"/>
+        <location filename="../SettingsDialog.qml" line="310"/>
         <source>Playback quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="291"/>
+        <location filename="../SettingsDialog.qml" line="319"/>
         <source>Download quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="299"/>
+        <location filename="../SettingsDialog.qml" line="285"/>
         <source>Start downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="307"/>
+        <location filename="../SettingsDialog.qml" line="353"/>
+        <source>Appearance</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="378"/>
+        <source>System</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="386"/>
         <source>Download location</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="323"/>
+        <location filename="../SettingsDialog.qml" line="395"/>
         <source>Screen orientation</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="331"/>
+        <location filename="../SettingsDialog.qml" line="301"/>
         <source>Media player</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="168"/>
-        <location filename="../SettingsDialog.qml" line="348"/>
-        <location filename="../SettingsDialog.qml" line="540"/>
+        <location filename="../SettingsDialog.qml" line="170"/>
+        <location filename="../SettingsDialog.qml" line="370"/>
+        <location filename="../SettingsDialog.qml" line="372"/>
         <source>Language</source>
         <translation></translation>
     </message>
@@ -505,38 +523,38 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="120"/>
-        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="122"/>
+        <location filename="../SettingsDialog.qml" line="173"/>
         <source>Network Proxy</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="144"/>
-        <location filename="../SettingsDialog.qml" line="394"/>
+        <location filename="../SettingsDialog.qml" line="146"/>
+        <location filename="../SettingsDialog.qml" line="312"/>
         <source>Playback Quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="147"/>
-        <location filename="../SettingsDialog.qml" line="412"/>
+        <location filename="../SettingsDialog.qml" line="149"/>
+        <location filename="../SettingsDialog.qml" line="321"/>
         <source>Download Quality</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="150"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="152"/>
+        <location filename="../SettingsDialog.qml" line="287"/>
         <source>Start Downloads</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="159"/>
-        <location filename="../SettingsDialog.qml" line="486"/>
+        <location filename="../SettingsDialog.qml" line="161"/>
+        <location filename="../SettingsDialog.qml" line="397"/>
         <source>Screen Orientation</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="162"/>
-        <location filename="../SettingsDialog.qml" line="504"/>
+        <location filename="../SettingsDialog.qml" line="164"/>
+        <location filename="../SettingsDialog.qml" line="303"/>
         <source>Media Player</source>
         <translation></translation>
     </message>
@@ -637,95 +655,115 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="105"/>
+        <location filename="../SettingsDialog.qml" line="107"/>
         <source>Your settings have been saved</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="110"/>
-        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="112"/>
+        <location filename="../SettingsDialog.qml" line="155"/>
         <source>Download Path</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="112"/>
+        <location filename="../SettingsDialog.qml" line="114"/>
         <source>Download Location</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="156"/>
-        <location filename="../SettingsDialog.qml" line="468"/>
+        <location filename="../SettingsDialog.qml" line="158"/>
+        <location filename="../SettingsDialog.qml" line="337"/>
         <source>Safe Search</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="165"/>
-        <location filename="../SettingsDialog.qml" line="339"/>
-        <location filename="../SettingsDialog.qml" line="522"/>
+        <location filename="../SettingsDialog.qml" line="167"/>
+        <location filename="../SettingsDialog.qml" line="361"/>
+        <location filename="../SettingsDialog.qml" line="363"/>
         <source>Theme</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="174"/>
-        <location filename="../SettingsDialog.qml" line="623"/>
+        <location filename="../SettingsDialog.qml" line="176"/>
+        <location filename="../SettingsDialog.qml" line="421"/>
         <source>Widget Feed One</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="177"/>
-        <location filename="../SettingsDialog.qml" line="643"/>
+        <location filename="../SettingsDialog.qml" line="179"/>
+        <location filename="../SettingsDialog.qml" line="430"/>
         <source>Widget Feed Two</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="180"/>
-        <location filename="../SettingsDialog.qml" line="663"/>
+        <location filename="../SettingsDialog.qml" line="182"/>
+        <location filename="../SettingsDialog.qml" line="439"/>
         <source>Widget Feed Three</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="183"/>
-        <location filename="../SettingsDialog.qml" line="683"/>
+        <location filename="../SettingsDialog.qml" line="185"/>
+        <location filename="../SettingsDialog.qml" line="448"/>
         <source>Widget Feed Four</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="275"/>
+        <location filename="../SettingsDialog.qml" line="268"/>
+        <source>Network</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="276"/>
         <source>Network proxy</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="315"/>
+        <location filename="../SettingsDialog.qml" line="293"/>
+        <source>Media</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="327"/>
+        <source>YouTube searches</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="335"/>
         <source>Safe search</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="367"/>
+        <location filename="../SettingsDialog.qml" line="411"/>
+        <source>Widget</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="419"/>
+        <source>Feed one</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="428"/>
+        <source>Feed two</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="437"/>
+        <source>Feed three</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="446"/>
+        <source>Feed four</source>
+        <translation></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>None</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="572"/>
-        <source>Feed One</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="580"/>
-        <source>Feed Two</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="588"/>
-        <source>Feed Three</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="596"/>
-        <source>Feed Four</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="698"/>
+        <location filename="../SettingsDialog.qml" line="346"/>
         <source>Clear saved searches</source>
         <translation></translation>
     </message>
@@ -748,7 +786,7 @@
     <message>
         <location filename="../SubscriptionsView.qml" line="45"/>
         <source>You have unsubscribed to this channel</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="104"/>
@@ -836,7 +874,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="35"/>
-        <location filename="../UploadDialog.qml" line="215"/>
+        <location filename="../UploadDialog.qml" line="216"/>
         <source>Category</source>
         <translation></translation>
     </message>
@@ -846,33 +884,33 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="138"/>
+        <location filename="../UploadDialog.qml" line="139"/>
         <source>File</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="147"/>
-        <location filename="../UploadDialog.qml" line="223"/>
+        <location filename="../UploadDialog.qml" line="148"/>
+        <location filename="../UploadDialog.qml" line="224"/>
         <source>None chosen</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="163"/>
+        <location filename="../UploadDialog.qml" line="164"/>
         <source>Title</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="176"/>
+        <location filename="../UploadDialog.qml" line="177"/>
         <source>Description (optional)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="188"/>
+        <location filename="../UploadDialog.qml" line="189"/>
         <source>Tags (seperated by commas)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="201"/>
+        <location filename="../UploadDialog.qml" line="202"/>
         <source>Private?</source>
         <translation></translation>
     </message>
@@ -1042,7 +1080,7 @@
     <message>
         <location filename="../VideoInfoView.qml" line="524"/>
         <source>No tags</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../VideoInfoView.qml" line="591"/>
@@ -1083,7 +1121,7 @@
     <message>
         <location filename="../VideoListView.qml" line="70"/>
         <source>Video(s) deleted from favourites</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../VideoListView.qml" line="92"/>
@@ -1168,11 +1206,6 @@
         <source>New playlist created</source>
         <translation></translation>
     </message>
-    <message>
-        <location filename="../main.qml" line="207"/>
-        <source>Audio</source>
-        <translation></translation>
-    </message>
     <message>
         <location filename="../main.qml" line="212"/>
         <source>Conversion of &apos;</source>
@@ -1184,47 +1217,22 @@
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="228"/>
-        <source>High quality</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>Mobile</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>360p</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>480p</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>720p</source>
-        <translation></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Queued</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Paused</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Downloading</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Failed</source>
         <translation></translation>
     </message>
@@ -1242,37 +1250,37 @@
 <context>
     <name>mainscripts</name>
     <message>
-        <location filename="../scripts/mainscripts.js" line="143"/>
+        <location filename="../scripts/mainscripts.js" line="146"/>
         <source>My Channel</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="158"/>
+        <location filename="../scripts/mainscripts.js" line="161"/>
         <source>Archive</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="197"/>
+        <location filename="../scripts/mainscripts.js" line="200"/>
         <source>My Playlists</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="207"/>
+        <location filename="../scripts/mainscripts.js" line="210"/>
         <source>My Subscriptions</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="220"/>
+        <location filename="../scripts/mainscripts.js" line="223"/>
         <source>Video Info</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="230"/>
+        <location filename="../scripts/mainscripts.js" line="233"/>
         <source>Video Playback</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="243"/>
+        <location filename="../scripts/mainscripts.js" line="246"/>
         <source>Search </source>
         <translation></translation>
     </message>
