@@ -24,14 +24,22 @@
         <translation type="obsolete">cuteTube-QML - 0.7.0 - Suomennos: d-iivil</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.1</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.1 - Suomennos: d-iivil</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.1 - Suomennos: d-iivil</translation>
+    </message>
+    <message>
+        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
+        <translation type="obsolete">Monipuolinen YouTube -clientti Nokia N900:lle. Tämä on QML käyttävä kehitysversio. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.3</source>
+        <translation type="unfinished">cuteTube-QML - 0.7.3 - Suomennos: d-iivil</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
-        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
-        <translation>Monipuolinen YouTube -clientti Nokia N900:lle. Tämä on QML käyttävä kehitysversio. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
+        <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -127,13 +135,13 @@
         <translation type="obsolete">Poista laitteesta</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="27"/>
+        <location filename="../ArchiveListView.qml" line="33"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="30"/>
-        <location filename="../ArchiveListView.qml" line="47"/>
+        <location filename="../ArchiveListView.qml" line="36"/>
+        <location filename="../ArchiveListView.qml" line="53"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -215,22 +223,22 @@
         <translation type="obsolete">Puolalainen</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="188"/>
+        <location filename="../../../controller.cpp" line="189"/>
         <source>Video deleted from device</source>
         <translation>Video poistettu laitteesta</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="191"/>
+        <location filename="../../../controller.cpp" line="192"/>
         <source>Unable to delete video</source>
         <translation>Videon poisto epäonnistui</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="195"/>
+        <location filename="../../../controller.cpp" line="196"/>
         <source>Video not found</source>
         <translation>Videota ei löytynyt</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="250"/>
+        <location filename="../../../controller.cpp" line="251"/>
         <source>Copied to clipboard</source>
         <translation>Kopioitu leikepöydälle</translation>
     </message>
@@ -326,6 +334,11 @@
         <source>Exit</source>
         <translation type="obsolete">Poistu</translation>
     </message>
+    <message>
+        <location filename="../MenuBar.qml" line="130"/>
+        <source>Sort</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MyAccountView</name>
@@ -637,8 +650,8 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="162"/>
-        <location filename="../SettingsDialog.qml" line="504"/>
+        <location filename="../SettingsDialog.qml" line="164"/>
+        <location filename="../SettingsDialog.qml" line="303"/>
         <source>Media Player</source>
         <translation>Mediasoitin</translation>
     </message>
@@ -712,177 +725,207 @@
         <translation type="obsolete">Pysäytetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="105"/>
+        <location filename="../SettingsDialog.qml" line="107"/>
         <source>Your settings have been saved</source>
         <translation>Asetukset tallennettu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="110"/>
-        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="112"/>
+        <location filename="../SettingsDialog.qml" line="155"/>
         <source>Download Path</source>
         <translation>Latauspolku</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="112"/>
+        <location filename="../SettingsDialog.qml" line="114"/>
         <source>Download Location</source>
         <translation>Lataussijainti</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="120"/>
-        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="122"/>
+        <location filename="../SettingsDialog.qml" line="173"/>
         <source>Network Proxy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="144"/>
-        <location filename="../SettingsDialog.qml" line="394"/>
+        <location filename="../SettingsDialog.qml" line="146"/>
+        <location filename="../SettingsDialog.qml" line="312"/>
         <source>Playback Quality</source>
         <translation>Toistolaatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="147"/>
-        <location filename="../SettingsDialog.qml" line="412"/>
+        <location filename="../SettingsDialog.qml" line="149"/>
+        <location filename="../SettingsDialog.qml" line="321"/>
         <source>Download Quality</source>
         <translation>Latauksen laatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="150"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="152"/>
+        <location filename="../SettingsDialog.qml" line="287"/>
         <source>Start Downloads</source>
         <translation>Käynnistä lataukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="156"/>
-        <location filename="../SettingsDialog.qml" line="468"/>
+        <location filename="../SettingsDialog.qml" line="158"/>
+        <location filename="../SettingsDialog.qml" line="337"/>
         <source>Safe Search</source>
         <translation>Turvallinen Haku</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="159"/>
-        <location filename="../SettingsDialog.qml" line="486"/>
+        <location filename="../SettingsDialog.qml" line="161"/>
+        <location filename="../SettingsDialog.qml" line="397"/>
         <source>Screen Orientation</source>
         <translation>Käyttöliittymän suunta</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="165"/>
-        <location filename="../SettingsDialog.qml" line="339"/>
-        <location filename="../SettingsDialog.qml" line="522"/>
+        <location filename="../SettingsDialog.qml" line="167"/>
+        <location filename="../SettingsDialog.qml" line="361"/>
+        <location filename="../SettingsDialog.qml" line="363"/>
         <source>Theme</source>
         <translation>Teema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="168"/>
-        <location filename="../SettingsDialog.qml" line="348"/>
-        <location filename="../SettingsDialog.qml" line="540"/>
+        <location filename="../SettingsDialog.qml" line="170"/>
+        <location filename="../SettingsDialog.qml" line="370"/>
+        <location filename="../SettingsDialog.qml" line="372"/>
         <source>Language</source>
         <translation>Kieli</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="174"/>
-        <location filename="../SettingsDialog.qml" line="623"/>
+        <location filename="../SettingsDialog.qml" line="176"/>
+        <location filename="../SettingsDialog.qml" line="421"/>
         <source>Widget Feed One</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="177"/>
-        <location filename="../SettingsDialog.qml" line="643"/>
+        <location filename="../SettingsDialog.qml" line="179"/>
+        <location filename="../SettingsDialog.qml" line="430"/>
         <source>Widget Feed Two</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="180"/>
-        <location filename="../SettingsDialog.qml" line="663"/>
+        <location filename="../SettingsDialog.qml" line="182"/>
+        <location filename="../SettingsDialog.qml" line="439"/>
         <source>Widget Feed Three</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="183"/>
-        <location filename="../SettingsDialog.qml" line="683"/>
+        <location filename="../SettingsDialog.qml" line="185"/>
+        <location filename="../SettingsDialog.qml" line="448"/>
         <source>Widget Feed Four</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="192"/>
+        <location filename="../SettingsDialog.qml" line="194"/>
         <source>Your saved searches have been cleared</source>
         <translation>Tallennetut hakusanat on tyhjennetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="195"/>
+        <location filename="../SettingsDialog.qml" line="197"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Tietokantavirhe. Hakuja ei tyhjennetty</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="242"/>
+        <location filename="../SettingsDialog.qml" line="244"/>
         <source>Settings</source>
         <translation>Asetukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="275"/>
+        <location filename="../SettingsDialog.qml" line="268"/>
+        <source>Network</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="276"/>
         <source>Network proxy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="283"/>
+        <location filename="../SettingsDialog.qml" line="293"/>
+        <source>Media</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="310"/>
         <source>Playback quality</source>
         <translation>Toistolaatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="291"/>
+        <location filename="../SettingsDialog.qml" line="319"/>
         <source>Download quality</source>
         <translation>Latauksien laatu</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="299"/>
+        <location filename="../SettingsDialog.qml" line="411"/>
+        <source>Widget</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="419"/>
+        <source>Feed one</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="428"/>
+        <source>Feed two</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="437"/>
+        <source>Feed three</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="446"/>
+        <source>Feed four</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="285"/>
         <source>Start downloads</source>
         <translation>Aloita lataukset</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="307"/>
+        <location filename="../SettingsDialog.qml" line="327"/>
+        <source>YouTube searches</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="353"/>
+        <source>Appearance</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="378"/>
+        <source>System</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="386"/>
         <source>Download location</source>
         <translation>Latauskansio</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="315"/>
+        <location filename="../SettingsDialog.qml" line="335"/>
         <source>Safe search</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="323"/>
+        <location filename="../SettingsDialog.qml" line="395"/>
         <source>Screen orientation</source>
         <translation>Käyttöliittymän suunta</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="331"/>
+        <location filename="../SettingsDialog.qml" line="301"/>
         <source>Media player</source>
         <translation>Mediasoitin</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="367"/>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>None</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="572"/>
-        <source>Feed One</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="580"/>
-        <source>Feed Two</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="588"/>
-        <source>Feed Three</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="596"/>
-        <source>Feed Four</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="698"/>
+        <location filename="../SettingsDialog.qml" line="346"/>
         <source>Clear saved searches</source>
         <translation>Tyhjennä hakusanat</translation>
     </message>
@@ -1001,7 +1044,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="35"/>
-        <location filename="../UploadDialog.qml" line="215"/>
+        <location filename="../UploadDialog.qml" line="216"/>
         <source>Category</source>
         <translation>Kategoria</translation>
     </message>
@@ -1011,33 +1054,33 @@
         <translation>Lataa video</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="138"/>
+        <location filename="../UploadDialog.qml" line="139"/>
         <source>File</source>
         <translation>Tiedosto</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="147"/>
-        <location filename="../UploadDialog.qml" line="223"/>
+        <location filename="../UploadDialog.qml" line="148"/>
+        <location filename="../UploadDialog.qml" line="224"/>
         <source>None chosen</source>
         <translation>Ei valittuja</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="163"/>
+        <location filename="../UploadDialog.qml" line="164"/>
         <source>Title</source>
         <translation>Otsikko</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="176"/>
+        <location filename="../UploadDialog.qml" line="177"/>
         <source>Description (optional)</source>
         <translation>Kuvaus (valinnainen)</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="188"/>
+        <location filename="../UploadDialog.qml" line="189"/>
         <source>Tags (seperated by commas)</source>
         <translation>Tagit (eroittele pilkulla)</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="201"/>
+        <location filename="../UploadDialog.qml" line="202"/>
         <source>Private?</source>
         <translation>Yksityinen?</translation>
     </message>
@@ -1507,11 +1550,6 @@
         <source>Converting</source>
         <translation type="obsolete">Muunnetaan</translation>
     </message>
-    <message>
-        <location filename="../main.qml" line="207"/>
-        <source>Audio</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../main.qml" line="212"/>
         <source>Conversion of &apos;</source>
@@ -1523,47 +1561,26 @@
         <translation> epäonnistui</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="228"/>
-        <source>High quality</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
         <source>Mobile</source>
-        <translation type="unfinished">Mobiili</translation>
+        <translation type="obsolete">Mobiili</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="228"/>
-        <source>360p</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>480p</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>720p</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Queued</source>
         <translation>Jonossa</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Paused</source>
         <translation>Keskeytetty</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Downloading</source>
-        <translation type="unfinished">Ladataan</translation>
+        <translation>Ladataan</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Failed</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1585,32 +1602,32 @@
         <translation type="obsolete">Mediasoitin</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="143"/>
+        <location filename="../scripts/mainscripts.js" line="146"/>
         <source>My Channel</source>
         <translation>Oma kanavani</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="158"/>
+        <location filename="../scripts/mainscripts.js" line="161"/>
         <source>Archive</source>
         <translation>Arkisto</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="197"/>
+        <location filename="../scripts/mainscripts.js" line="200"/>
         <source>My Playlists</source>
         <translation>Omat soittolistani</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="207"/>
+        <location filename="../scripts/mainscripts.js" line="210"/>
         <source>My Subscriptions</source>
         <translation>Omat tilaukseni</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="220"/>
+        <location filename="../scripts/mainscripts.js" line="223"/>
         <source>Video Info</source>
         <translation>Videon tiedot</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="230"/>
+        <location filename="../scripts/mainscripts.js" line="233"/>
         <source>Video Playback</source>
         <translation>Videon toisto</translation>
     </message>
@@ -1635,7 +1652,7 @@
         <translation type="obsolete">arvio</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="243"/>
+        <location filename="../scripts/mainscripts.js" line="246"/>
         <source>Search </source>
         <translation>Haku</translation>
     </message>
