@@ -15,7 +15,7 @@
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
         <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
-        <translation type="unfinished"></translation>
+        <translation>Un client YouTube ricco di funzioni che permette di visualizzare, riprodurre e scaricare video,ed in più una gestione account completa. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
     </message>
 </context>
 <context>
@@ -109,13 +109,13 @@
     <message>
         <location filename="../ArchiveListView.qml" line="33"/>
         <source>Deleted from archive</source>
-        <translation type="unfinished"></translation>
+        <translation>Cancellato dall&apos;archivio</translation>
     </message>
     <message>
         <location filename="../ArchiveListView.qml" line="36"/>
         <location filename="../ArchiveListView.qml" line="53"/>
         <source>Unable to delete from archive</source>
-        <translation type="unfinished"></translation>
+        <translation>Impossibile cancellare dall&apos;archivio</translation>
     </message>
 </context>
 <context>
@@ -293,7 +293,7 @@
     <message>
         <location filename="../MenuBar.qml" line="130"/>
         <source>Sort</source>
-        <translation type="unfinished"></translation>
+        <translation>Ordina</translation>
     </message>
 </context>
 <context>
@@ -448,7 +448,7 @@
     <message>
         <location filename="../PlaylistVideosView.qml" line="59"/>
         <source>Video(s) deleted from playlist</source>
-        <translation type="unfinished"></translation>
+        <translation>Video cancellato(i) dalla playlist</translation>
     </message>
     <message>
         <location filename="../PlaylistVideosView.qml" line="80"/>
@@ -478,17 +478,17 @@
     <message>
         <location filename="../ProxyDialog.qml" line="30"/>
         <source>Network Proxy</source>
-        <translation></translation>
+        <translation>Rete Proxy</translation>
     </message>
     <message>
         <location filename="../ProxyDialog.qml" line="44"/>
         <source>Host (e.g. 192.168.100.1)</source>
-        <translation></translation>
+        <translation>Host (es. 192.168.100.1)</translation>
     </message>
     <message>
         <location filename="../ProxyDialog.qml" line="51"/>
         <source>Port (e.g. 8080)</source>
-        <translation></translation>
+        <translation>Port (es. 8080)</translation>
     </message>
 </context>
 <context>
@@ -579,7 +579,7 @@
     <message>
         <location filename="../SettingsDialog.qml" line="44"/>
         <source>Most viewed</source>
-        <translation>I più recenti</translation>
+        <translation>I più visti</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="45"/>
@@ -621,17 +621,17 @@
     <message>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>360p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>480p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="38"/>
         <source>720p</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="42"/>
@@ -696,7 +696,7 @@
         <location filename="../SettingsDialog.qml" line="122"/>
         <location filename="../SettingsDialog.qml" line="173"/>
         <source>Network Proxy</source>
-        <translation></translation>
+        <translation>Rete Proxy</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="146"/>
@@ -784,17 +784,17 @@
     <message>
         <location filename="../SettingsDialog.qml" line="268"/>
         <source>Network</source>
-        <translation type="unfinished"></translation>
+        <translation>Rete</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="276"/>
         <source>Network proxy</source>
-        <translation></translation>
+        <translation>Rete proxy</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="293"/>
         <source>Media</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="310"/>
@@ -809,27 +809,27 @@
     <message>
         <location filename="../SettingsDialog.qml" line="411"/>
         <source>Widget</source>
-        <translation type="unfinished"></translation>
+        <translation></translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="419"/>
         <source>Feed one</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed uno</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="428"/>
         <source>Feed two</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed due</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="437"/>
         <source>Feed three</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed tre</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="446"/>
         <source>Feed four</source>
-        <translation type="unfinished"></translation>
+        <translation>Feed quattro</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="285"/>
@@ -839,17 +839,17 @@
     <message>
         <location filename="../SettingsDialog.qml" line="327"/>
         <source>YouTube searches</source>
-        <translation type="unfinished"></translation>
+        <translation>Ricerche YouTube</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="353"/>
         <source>Appearance</source>
-        <translation type="unfinished"></translation>
+        <translation>Aspetto</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="378"/>
         <source>System</source>
-        <translation type="unfinished"></translation>
+        <translation>Sistema</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="386"/>
@@ -911,12 +911,12 @@
     <message>
         <location filename="../SubscriptionsView.qml" line="36"/>
         <source>Latest Subscriptions Videos</source>
-        <translation type="unfinished"></translation>
+        <translation>Novità da Iscrizioni</translation>
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="45"/>
         <source>You have unsubscribed to this channel</source>
-        <translation type="unfinished"></translation>
+        <translation>Ti sei cancellato da questo canale</translation>
     </message>
     <message>
         <source>You have unsubscribed to &apos;</source>
@@ -1249,12 +1249,12 @@
     <message>
         <location filename="../VideoInfoView.qml" line="514"/>
         <source>Tags</source>
-        <translation></translation>
+        <translation>Tag</translation>
     </message>
     <message>
         <location filename="../VideoInfoView.qml" line="524"/>
         <source>No tags</source>
-        <translation type="unfinished"></translation>
+        <translation>Nessun Tag</translation>
     </message>
     <message>
         <location filename="../VideoInfoView.qml" line="591"/>
@@ -1315,7 +1315,7 @@
     <message>
         <location filename="../VideoListView.qml" line="70"/>
         <source>Video(s) deleted from favourites</source>
-        <translation type="unfinished"></translation>
+        <translation>Video cancellato(i) dai preferiti</translation>
     </message>
     <message>
         <location filename="../VideoListView.qml" line="92"/>
