@@ -12,14 +12,22 @@
         <translation type="obsolete">cuteTube-QML - 0.7.0</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.7.1</source>
-        <translation type="unfinished">cuteTube-QML - 0.7.1</translation>
+        <translation type="obsolete">cuteTube-QML - 0.7.1</translation>
+    </message>
+    <message>
+        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
+        <translation type="obsolete">Клиент YouTube для Nokia N900. Это экспериментальный выпуск на QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.7.3</source>
+        <translation type="unfinished">cuteTube-QML - 0.7.3</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
-        <source>A feature-rich YouTube client for the Nokia N900. This is an experimental release using QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
-        <translation>Клиент YouTube для Nokia N900. Это экспериментальный выпуск на QML. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</translation>
+        <source>A feature-rich YouTube client enabling browsing, playback and download of videos, plus account management. &lt;br&gt;&lt;br&gt; &amp;copy; Stuart Howarth 2011</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -115,13 +123,13 @@
         <translation type="obsolete">Удалить с устройства</translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="27"/>
+        <location filename="../ArchiveListView.qml" line="33"/>
         <source>Deleted from archive</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../ArchiveListView.qml" line="30"/>
-        <location filename="../ArchiveListView.qml" line="47"/>
+        <location filename="../ArchiveListView.qml" line="36"/>
+        <location filename="../ArchiveListView.qml" line="53"/>
         <source>Unable to delete from archive</source>
         <translation type="unfinished"></translation>
     </message>
@@ -199,22 +207,22 @@
         <translation type="obsolete">Финский</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="188"/>
+        <location filename="../../../controller.cpp" line="189"/>
         <source>Video deleted from device</source>
         <translation>Видео удалено с устройства</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="191"/>
+        <location filename="../../../controller.cpp" line="192"/>
         <source>Unable to delete video</source>
         <translation>Невозможно удалить видео</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="195"/>
+        <location filename="../../../controller.cpp" line="196"/>
         <source>Video not found</source>
         <translation>Видео не найдено</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="250"/>
+        <location filename="../../../controller.cpp" line="251"/>
         <source>Copied to clipboard</source>
         <translation>Скопировано в буфер</translation>
     </message>
@@ -310,6 +318,11 @@
         <source>Exit</source>
         <translation type="obsolete">Выход</translation>
     </message>
+    <message>
+        <location filename="../MenuBar.qml" line="130"/>
+        <source>Sort</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MyAccountView</name>
@@ -541,54 +554,64 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="192"/>
+        <location filename="../SettingsDialog.qml" line="194"/>
         <source>Your saved searches have been cleared</source>
         <translation>Сохраненные поисковые запросы очищены</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="195"/>
+        <location filename="../SettingsDialog.qml" line="197"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Ошибка базы данных. Невозможно очистить запросы</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="242"/>
+        <location filename="../SettingsDialog.qml" line="244"/>
         <source>Settings</source>
         <translation>Настройки</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="283"/>
+        <location filename="../SettingsDialog.qml" line="310"/>
         <source>Playback quality</source>
         <translation>Качество проигрывания</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="291"/>
+        <location filename="../SettingsDialog.qml" line="319"/>
         <source>Download quality</source>
         <translation>Качество загрузки</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="299"/>
+        <location filename="../SettingsDialog.qml" line="285"/>
         <source>Start downloads</source>
         <translation>Начать загрузки</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="307"/>
+        <location filename="../SettingsDialog.qml" line="353"/>
+        <source>Appearance</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="378"/>
+        <source>System</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="386"/>
         <source>Download location</source>
         <translation>Директория загрузки</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="323"/>
+        <location filename="../SettingsDialog.qml" line="395"/>
         <source>Screen orientation</source>
         <translation>Ориентация экрана</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="331"/>
+        <location filename="../SettingsDialog.qml" line="301"/>
         <source>Media player</source>
         <translation>Проигрыватель</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="168"/>
-        <location filename="../SettingsDialog.qml" line="348"/>
-        <location filename="../SettingsDialog.qml" line="540"/>
+        <location filename="../SettingsDialog.qml" line="170"/>
+        <location filename="../SettingsDialog.qml" line="370"/>
+        <location filename="../SettingsDialog.qml" line="372"/>
         <source>Language</source>
         <translation>Язык</translation>
     </message>
@@ -659,41 +682,66 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="120"/>
-        <location filename="../SettingsDialog.qml" line="171"/>
+        <location filename="../SettingsDialog.qml" line="122"/>
+        <location filename="../SettingsDialog.qml" line="173"/>
         <source>Network Proxy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="144"/>
-        <location filename="../SettingsDialog.qml" line="394"/>
+        <location filename="../SettingsDialog.qml" line="146"/>
+        <location filename="../SettingsDialog.qml" line="312"/>
         <source>Playback Quality</source>
         <translation>Качество Проигрывания</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="147"/>
-        <location filename="../SettingsDialog.qml" line="412"/>
+        <location filename="../SettingsDialog.qml" line="149"/>
+        <location filename="../SettingsDialog.qml" line="321"/>
         <source>Download Quality</source>
         <translation>Качество Загрузки</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="150"/>
-        <location filename="../SettingsDialog.qml" line="430"/>
+        <location filename="../SettingsDialog.qml" line="152"/>
+        <location filename="../SettingsDialog.qml" line="287"/>
         <source>Start Downloads</source>
         <translation>Начать Загрузки</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="159"/>
-        <location filename="../SettingsDialog.qml" line="486"/>
+        <location filename="../SettingsDialog.qml" line="161"/>
+        <location filename="../SettingsDialog.qml" line="397"/>
         <source>Screen Orientation</source>
         <translation>Ориентация Экрана</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="162"/>
-        <location filename="../SettingsDialog.qml" line="504"/>
+        <location filename="../SettingsDialog.qml" line="164"/>
+        <location filename="../SettingsDialog.qml" line="303"/>
         <source>Media Player</source>
         <translation>Проигрыватель</translation>
     </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="411"/>
+        <source>Widget</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="419"/>
+        <source>Feed one</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="428"/>
+        <source>Feed two</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="437"/>
+        <source>Feed three</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="446"/>
+        <source>Feed four</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../SettingsDialog.qml" line="37"/>
         <location filename="../SettingsDialog.qml" line="38"/>
@@ -778,95 +826,90 @@
         <translation type="obsolete">Пауза</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="105"/>
+        <location filename="../SettingsDialog.qml" line="107"/>
         <source>Your settings have been saved</source>
         <translation>Настройки сохранены</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="110"/>
-        <location filename="../SettingsDialog.qml" line="153"/>
+        <location filename="../SettingsDialog.qml" line="112"/>
+        <location filename="../SettingsDialog.qml" line="155"/>
         <source>Download Path</source>
         <translation>Директория Загрузки</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="112"/>
+        <location filename="../SettingsDialog.qml" line="114"/>
         <source>Download Location</source>
         <translation>Директория Загрузки</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="156"/>
-        <location filename="../SettingsDialog.qml" line="468"/>
+        <location filename="../SettingsDialog.qml" line="158"/>
+        <location filename="../SettingsDialog.qml" line="337"/>
         <source>Safe Search</source>
         <translation>Безопасный Поиск</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="165"/>
-        <location filename="../SettingsDialog.qml" line="339"/>
-        <location filename="../SettingsDialog.qml" line="522"/>
+        <location filename="../SettingsDialog.qml" line="167"/>
+        <location filename="../SettingsDialog.qml" line="361"/>
+        <location filename="../SettingsDialog.qml" line="363"/>
         <source>Theme</source>
         <translation>Тема</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="174"/>
-        <location filename="../SettingsDialog.qml" line="623"/>
+        <location filename="../SettingsDialog.qml" line="176"/>
+        <location filename="../SettingsDialog.qml" line="421"/>
         <source>Widget Feed One</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="177"/>
-        <location filename="../SettingsDialog.qml" line="643"/>
+        <location filename="../SettingsDialog.qml" line="179"/>
+        <location filename="../SettingsDialog.qml" line="430"/>
         <source>Widget Feed Two</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="180"/>
-        <location filename="../SettingsDialog.qml" line="663"/>
+        <location filename="../SettingsDialog.qml" line="182"/>
+        <location filename="../SettingsDialog.qml" line="439"/>
         <source>Widget Feed Three</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="183"/>
-        <location filename="../SettingsDialog.qml" line="683"/>
+        <location filename="../SettingsDialog.qml" line="185"/>
+        <location filename="../SettingsDialog.qml" line="448"/>
         <source>Widget Feed Four</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="275"/>
+        <location filename="../SettingsDialog.qml" line="268"/>
+        <source>Network</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="276"/>
         <source>Network proxy</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="315"/>
+        <location filename="../SettingsDialog.qml" line="293"/>
+        <source>Media</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="327"/>
+        <source>YouTube searches</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="335"/>
         <source>Safe search</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="367"/>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>None</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="572"/>
-        <source>Feed One</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="580"/>
-        <source>Feed Two</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="588"/>
-        <source>Feed Three</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="596"/>
-        <source>Feed Four</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../SettingsDialog.qml" line="698"/>
+        <location filename="../SettingsDialog.qml" line="346"/>
         <source>Clear saved searches</source>
         <translation>Очистить поисковые запросы</translation>
     </message>
@@ -985,7 +1028,7 @@
     </message>
     <message>
         <location filename="../UploadDialog.qml" line="35"/>
-        <location filename="../UploadDialog.qml" line="215"/>
+        <location filename="../UploadDialog.qml" line="216"/>
         <source>Category</source>
         <translation>Категория</translation>
     </message>
@@ -995,33 +1038,33 @@
         <translation>Загрузить Видео</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="138"/>
+        <location filename="../UploadDialog.qml" line="139"/>
         <source>File</source>
         <translation>Файл</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="147"/>
-        <location filename="../UploadDialog.qml" line="223"/>
+        <location filename="../UploadDialog.qml" line="148"/>
+        <location filename="../UploadDialog.qml" line="224"/>
         <source>None chosen</source>
         <translation>Не выбрано</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="163"/>
+        <location filename="../UploadDialog.qml" line="164"/>
         <source>Title</source>
         <translation>Название</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="176"/>
+        <location filename="../UploadDialog.qml" line="177"/>
         <source>Description (optional)</source>
         <translation>Описание (не обязательно)</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="188"/>
+        <location filename="../UploadDialog.qml" line="189"/>
         <source>Tags (seperated by commas)</source>
         <translation>Теги (через запятую)</translation>
     </message>
     <message>
-        <location filename="../UploadDialog.qml" line="201"/>
+        <location filename="../UploadDialog.qml" line="202"/>
         <source>Private?</source>
         <translation>Частное?</translation>
     </message>
@@ -1407,11 +1450,6 @@
         <source>Converting</source>
         <translation type="obsolete">Конвертирую</translation>
     </message>
-    <message>
-        <location filename="../main.qml" line="207"/>
-        <source>Audio</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../main.qml" line="212"/>
         <source>Conversion of &apos;</source>
@@ -1423,47 +1461,26 @@
         <translation>&apos; не выполнена</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="228"/>
-        <source>High quality</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
         <source>Mobile</source>
-        <translation type="unfinished">Мобильное</translation>
+        <translation type="obsolete">Мобильное</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="228"/>
-        <source>360p</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>480p</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="228"/>
-        <source>720p</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Queued</source>
         <translation>В очереди</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Paused</source>
         <translation>Пауза</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Downloading</source>
         <translation type="unfinished">Загружается</translation>
     </message>
     <message>
-        <location filename="../main.qml" line="229"/>
+        <location filename="../main.qml" line="226"/>
         <source>Failed</source>
         <translation type="unfinished">Ошибка</translation>
     </message>
@@ -1485,32 +1502,32 @@
         <translation type="obsolete">Проигрыватель</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="143"/>
+        <location filename="../scripts/mainscripts.js" line="146"/>
         <source>My Channel</source>
         <translation>Мой Канал</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="158"/>
+        <location filename="../scripts/mainscripts.js" line="161"/>
         <source>Archive</source>
         <translation>Архив</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="197"/>
+        <location filename="../scripts/mainscripts.js" line="200"/>
         <source>My Playlists</source>
         <translation>Мой Плейлисты</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="207"/>
+        <location filename="../scripts/mainscripts.js" line="210"/>
         <source>My Subscriptions</source>
         <translation>Мои Подписки</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="220"/>
+        <location filename="../scripts/mainscripts.js" line="223"/>
         <source>Video Info</source>
         <translation>Информация</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="230"/>
+        <location filename="../scripts/mainscripts.js" line="233"/>
         <source>Video Playback</source>
         <translation>Качество Видео</translation>
     </message>
@@ -1535,7 +1552,7 @@
         <translation type="obsolete">рейтингу</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="243"/>
+        <location filename="../scripts/mainscripts.js" line="246"/>
         <source>Search </source>
         <translation>Поиск </translation>
     </message>
