@@ -1,8 +1,14 @@
 /* Main view functions */
 
+var xTubeInstalled = false;
+
 function restoreSettings() {
     /* Restore the user's settings from the database */
 
+    if (Controller.xTubeInstalled()) {
+            Qt.include("xtube.js");
+            xTubeInstalled = true;
+    }
     Settings.initialize();
     cuteTubeTheme = Settings.getSetting("theme");
     Controller.setOrientation(Settings.getSetting("screenOrientation"));
@@ -236,7 +242,7 @@ function loadPlaybackView(videoList) {
     loader.item.playbackStopped.connect(stopPlaying);
 }
 
-function search(query, order) {
+function youtubeSearch(query, order) {
     /* Perform a YouTube search and open video list window */
 
     var encodedQuery = encodeURIComponent(query);
@@ -246,6 +252,28 @@ function search(query, order) {
     loadVideos(videoFeed, qsTr("Search ") + "('" + query + "')");
 }
 
+function search(query, order) {
+    /* Check if xTube is installed and parse the search query */
+
+    if (xTubeInstalled) {
+        var youjizz = /^yj:/i;
+        var xhamster = /^xh:/i;
+        if (youjizz.test(query)) {
+            youjizzSearch(query.substr(3), order);
+        }
+        else if (xhamster.test(query)) {
+            xhamsterSearch(query.substr(3), order);
+        }
+        else {
+            youtubeSearch(query, order);
+        }
+    }
+    else {
+        youtubeSearch(query, order);
+    }
+}
+
+
 function toggleMenu() {
     /* Show/hide the menu of the current view */
 
